The Apache Clownfish "symbiotic" object system pairs with "host" programming
language environments and facilitates the development of high performance
language extensions.
Host language support
Bindings for the following hosts are under development:
C (feature-complete)
Go (experimental)
Perl 5 (feature-complete)
Python 3 / CPython (nascent)
Ruby / MRI (nascent)
Installation
To build and install Apache Clownfish, follow the instructions in the
accompanying "INSTALL" document.
Help wanted
The target audience for the current release of Clownfish is developers.
Clownfish is developed by the Apache Lucy community, where it is used to
provide host language bindings for the Lucy search engine library; we expect
that as Clownfish matures it will eventually spin off as an independent
project. If you would like to contribute to Clownfish, please join the Lucy
developers mailing list.